# Welcome to Earthkit-climate's documentation!

**earthkit-climate** is a library of software tools to support people working with climate and meteorology data

**earthkit-climate** includes methods for aggregating data in time and space, and future versions will
include tools for bias correcting, downscaling climate data and standard caculations for climate metrics
(e.g. indicators and risk factors).
It has been designed following the philosphy of Earthkit, hence the methods should be interoperable with any
data object understood by earthkit-data.

```{toctree}
:caption: 'Contents:'
:maxdepth: 2

examples.md
API Reference <_api/index>
```

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
